@@ -40,7 +40,7 @@ get_component_data_from_NASIS_db <- function(SS = TRUE,
                                              nullFragsAreZero = TRUE,
                                              stringsAsFactors = default.stringsAsFactors(),
                                              dsn = NULL) {
-  
+
   q1 <- "SELECT dmudesc, compname, comppct_r, compkind, majcompflag, localphase, drainagecl, hydricrating, elev_l, elev_r, elev_h, slope_l, slope_r, slope_h, aspectccwise, aspectrep, aspectcwise, map_l, map_r, map_h, airtempa_l as maat_l, airtempa_r as maat_r, airtempa_h as maat_h, soiltempa_r as mast_r, reannualprecip_r, ffd_l, ffd_r, ffd_h, tfact, wei, weg, nirrcapcl, nirrcapscl, nirrcapunit, irrcapcl, irrcapscl, irrcapunit, frostact, hydricrating, hydgrp, corcon, corsteel, taxclname, taxorder, taxsuborder, taxgrtgroup, taxsubgrp, taxpartsize, taxpartsizemod, taxceactcl, taxreaction, taxtempcl, taxmoistscl, taxtempregime, soiltaxedition, coiid, dmuiid
 
   FROM
@@ -48,23 +48,23 @@ get_component_data_from_NASIS_db <- function(SS = TRUE,
   INNER JOIN component_View_1 AS co ON co.dmuiidref = dmu.dmuiid
 
   ORDER BY dmudesc, comppct_r DESC, compname ASC;"
-  
+
   q2 <- "SELECT * FROM cosurffrags_View_1"
-  
+
   channel <- dbConnectNASIS(dsn)
-  
+
   if (inherits(channel, 'try-error'))
     return(data.frame())
-  
+
   # toggle selected set vs. local DB
   if (SS == FALSE) {
     q1 <- gsub(pattern = '_View_1', replacement = '', x = q1, fixed = TRUE)
     q2 <- gsub(pattern = '_View_1', replacement = '', x = q2, fixed = TRUE)
   }
-  
+
   # exec query
   d <- dbQueryNASIS(channel, q1, close = FALSE)
-  
+
   # test for duplicate coiids
   idx <- which(table(d$coiid) > 1)
   if (length(idx) > 0) {
@@ -72,38 +72,41 @@ get_component_data_from_NASIS_db <- function(SS = TRUE,
     assign('dupe.coiids', value=dupes, envir=soilDB.env)
     message("-> QC: duplicate coiids, this should not happen.\n\tUse `get('dupe.coiids', envir=soilDB.env)` for component record IDs (coiid)")
   }
-  
-  # uncode metadata domains
-  if (nrow(d) > 0) {
-    d <- uncode(d, stringsAsFactors = stringsAsFactors, dsn = dsn)
-  }
-  
   # surface fragments
   chs <- simplifyFragmentData(
-    uncode(dbQueryNASIS(channel, q2, close = FALSE), dsn = dsn),
+    uncode(dbQueryNASIS(channel, q2), dsn = dsn),
     id.var = "coiidref",
     vol.var = "sfragcov_r",
     prefix = "sfrag",
     msg = "surface fragment cover")
   
-  if (sum(complete.cases(chs)) == 0) {
-    chs <- chs[1:nrow(d),]
-    chs$coiidref <- d$coiid
-  } else {
-    ldx <- !d$coiid %in% chs$coiidref
-    chs_null <- chs[0,][1:sum(ldx),]
-    chs_null$coiidref <- d$coiid[ldx]
-    chs <- rbind(chs, chs_null)
-    
-    # handle NA for totals
-    if (nullFragsAreZero) {
-      chs[is.na(chs)] <- 0
-    } 
-    colnames(chs) <- paste0("surface_", colnames(chs))
-    colnames(chs)[1] <- "coiidref"
-    d <- merge(d, chs, by.x = "coiid", by.y = "coiidref", all.x = TRUE, sort = FALSE)
-  }
+  colnames(chs) <- paste0("surface_", colnames(chs))
+  colnames(chs)[1] <- "coiidref"
   
+  # uncode metadata domains
+  if (nrow(d) > 0) {
+    d <- uncode(d, stringsAsFactors = stringsAsFactors, dsn = dsn)
+
+    if (sum(complete.cases(chs)) == 0) {
+      chs <- chs[1:nrow(d),]
+      chs$coiidref <- d$coiid
+    } else {
+      ldx <- !d$coiid %in% chs$coiidref
+      chs_null <- chs[0,][1:sum(ldx),]
+      chs_null$coiidref <- d$coiid[ldx]
+      chs <- rbind(chs, chs_null)
+
+      # handle NA for totals
+      if (nullFragsAreZero) {
+        chs[is.na(chs)] <- 0
+      } 
+      d <- merge(d, chs, by.x = "coiid", by.y = "coiidref", all.x = TRUE, sort = FALSE)
+    }
+  } else {
+    d <- cbind(d, chs[0,])
+  }
+
+
   # done
   return(d)
 }
@@ -157,8 +160,7 @@ get_component_restrictions_from_NASIS_db <- function(SS = TRUE, dsn = NULL) {
   d <- dbQueryNASIS(channel, q)
 
   # convert codes
-  return(uncode(d, dsn = dsn)
-)
+  return(uncode(d, dsn = dsn))
 }
 
 # return all rows from correlation -- map unit -- legend map unit -- dmu / legend -- area
@@ -172,7 +174,7 @@ get_component_correlation_data_from_NASIS_db <- function(SS = TRUE,
                                                          dropNotRepresentative = TRUE,
                                                          stringsAsFactors = default.stringsAsFactors(),
                                                          dsn = NULL) {
-  
+
   q <- "SELECT lmapunitiid, mu.muiid, musym, nationalmusym, mu.muname, mukind, mutype, mustatus, muacres, farmlndcl, repdmu, dmuiid, areasymbol, areaname, ssastatus, cordate
 
   FROM  mapunit_View_1 AS mu
@@ -275,7 +277,7 @@ get_component_cogeomorph_data_from_NASIS_db <- function(SS = TRUE, dsn = NULL) {
 #' @export
 #' @rdname get_component_data_from_NASIS_db
 get_component_cogeomorph_data_from_NASIS_db2 <- function(SS = TRUE, dsn = NULL) {
-  
+
   q <- "SELECT cogeo.coiidref as coiid, cogeo.geomfmod, geomorfeat.geomfname, cogeo.geomfeatid, cogeo.existsonfeat, cogeo.geomfiidref, lower(geomorfeattype.geomftname) as geomftname, cogeo.rvindicator AS cogeomordescrv, hillslopeprof, cosurfmorphhpp.rvindicator AS cosurfmorphhpprv, geomposmntn, geomposhill, geompostrce, geomposflats, shapeacross, shapedown, geomicrorelief
 
   FROM
@@ -288,21 +290,21 @@ get_component_cogeomorph_data_from_NASIS_db2 <- function(SS = TRUE, dsn = NULL)
   LEFT JOIN cosurfmorphmr ON cosurfmorphmr.cogeomdiidref = cogeo.cogeomdiid
   LEFT JOIN cosurfmorphss ON cosurfmorphss.cogeomdiidref = cogeo.cogeomdiid
   ORDER BY coiid, geomfeatid ASC;"
-  
+
   channel <- dbConnectNASIS(dsn)
-  
+
   if (inherits(channel, 'try-error'))
     return(data.frame())
-  
+
   # toggle selected set vs. local DB
   if (SS == FALSE) {
     q <- gsub(pattern = '_View_1', replacement = '', x = q, fixed = TRUE)
   }
-  
+
   d <- dbQueryNASIS(channel, q)
-  
+
   # done
-  return(uncode(d))
+  return(uncode(d, dsn = dsn))
 }
 
 # get copm for each component
@@ -311,7 +313,7 @@ get_component_cogeomorph_data_from_NASIS_db2 <- function(SS = TRUE, dsn = NULL)
 get_component_copm_data_from_NASIS_db <- function(SS = TRUE,
                                                   stringsAsFactors = default.stringsAsFactors(),
                                                   dsn = NULL) {
-  
+
 
   q <- "SELECT cpmg.coiidref as coiid, cpm.seqnum as seqnum, pmorder, pmdept_r, pmdepb_r, pmmodifier, pmgenmod, pmkind, pmorigin
 
@@ -347,7 +349,7 @@ get_component_copm_data_from_NASIS_db <- function(SS = TRUE,
 get_component_esd_data_from_NASIS_db <- function(SS = TRUE,
                                                  stringsAsFactors = default.stringsAsFactors(),
                                                  dsn = NULL) {
-  
+
   q <- "SELECT coiidref as coiid, ecositeid, ecositenm,
   ecositeorigin, ecositetype, ecositemlra, ecositelru, ecositenumber, ecositestate
 
@@ -389,7 +391,7 @@ get_component_esd_data_from_NASIS_db <- function(SS = TRUE,
 #' @export
 #' @rdname get_component_data_from_NASIS_db
 get_component_otherveg_data_from_NASIS_db <- function(SS = TRUE, dsn = NULL) {
-  
+
 
   q <- "SELECT coiidref as coiid, ovegclid, ovegclname, coothvegcl.recwlupdated
   FROM coothvegclass_View_1 coothvegcl
@@ -462,7 +464,7 @@ get_comonth_from_NASIS_db <- function(SS = TRUE,
                                       fill = FALSE,
                                       stringsAsFactors = default.stringsAsFactors(),
                                       dsn = NULL) {
-  
+
 
   q <- "SELECT coiidref AS coiid, month, flodfreqcl, floddurcl, pondfreqcl, ponddurcl, ponddep_l, ponddep_r, ponddep_h, dlyavgprecip_l, dlyavgprecip_r, dlyavgprecip_h, comonthiid
   FROM comonth_View_1 AS comonth;"
@@ -564,7 +566,7 @@ get_comonth_from_NASIS_db <- function(SS = TRUE,
 #' @export
 #' @rdname get_component_data_from_NASIS_db
 get_copedon_from_NASIS_db <- function(SS = TRUE, dsn = NULL) {
-  
+
   q <- "SELECT coiidref as coiid, peiidref as peiid, upedonid as pedon_id, rvindicator as representative
 
   FROM copedon_View_1 copedon
@@ -614,10 +616,10 @@ get_component_horizon_data_from_NASIS_db <- function(SS = TRUE,
   INNER JOIN datamapunit_View_1 dmu ON dmu.dmuiid = co.dmuiidref
 
   ORDER BY dmudesc, comppct_r DESC, compname ASC, hzdept_r ASC;"
-  
+
   q2 <- "SELECT * FROM chfrags_View_1"
   q3 <- "SELECT * FROM chhuarts_View_1"
-  
+
   channel <- dbConnectNASIS(dsn)
 
   if (inherits(channel, 'try-error'))
@@ -639,9 +641,9 @@ get_component_horizon_data_from_NASIS_db <- function(SS = TRUE,
   if (fill == FALSE) {
     d <- d[!is.na(d$chiid), ]
   }
-  
-  # "sieving" chfrags, chuarts tables for parity with fetchNASIS("pedons") @horizons slot columns 
-  
+
+  # "sieving" chfrags, chuarts tables for parity with fetchNASIS("pedons") @horizons slot columns
+
   if (nrow(d) > 0){
     # horizon fragments
     chf <- simplifyFragmentData(
@@ -665,9 +667,9 @@ get_component_horizon_data_from_NASIS_db <- function(SS = TRUE,
     # handle NA for totals
     if (nullFragsAreZero) {
       chf[is.na(chf)] <- 0
-    } 
-  
-    # human artifacts  
+    }
+
+    # human artifacts
     cha <- simplifyArtifactData(
       uncode(dbQueryNASIS(channel, q3, close = FALSE), dsn = dsn),
       id.var = "chiidref",
@@ -688,12 +690,12 @@ get_component_horizon_data_from_NASIS_db <- function(SS = TRUE,
     if (nullFragsAreZero) {
       cha[is.na(cha)] <- 0
     }
-    
-    
+
+
     d <- merge(d, chf, by.x = "chiid", by.y = "chiidref", all.x = TRUE, sort = FALSE)
     d <- merge(d, cha, by.x = "chiid", by.y = "chiidref", all.x = TRUE, sort = FALSE)
   }
-  
+
   return(d)
 }
 
